@@ -1,3 +1,4 @@
+import logging
 from unittest import TestCase
 
 from nix_prefetch_github.github import GithubAPIImpl
@@ -8,7 +9,8 @@ from nix_prefetch_github.tests import network
 @network
 class GithubTests(TestCase):
     def setUp(self) -> None:
-        self.api = GithubAPIImpl()
+        self.logger = logging.getLogger()
+        self.api = GithubAPIImpl(logger=self.logger)
 
     def test_that_for_own_repo_latest_release_is_not_none(self) -> None:
         self.assertIsNotNone(
