@@ -8,7 +8,6 @@ from nix_prefetch_github.interfaces import (
     Prefetcher,
     PrefetchOptions,
     Presenter,
-    RenderingFormat,
     RepositoryDetector,
 )
 
@@ -21,15 +20,13 @@ class PrefetchDirectoryUseCase(Protocol):
 @dataclass
 class Request:
     prefetch_options: PrefetchOptions
-    rendering_format: RenderingFormat
     directory: str
     remote: str
 
 
 @dataclass
 class PrefetchDirectoryUseCaseImpl:
-    nix_presenter: Presenter
-    json_presenter: Presenter
+    presenter: Presenter
     prefetcher: Prefetcher
     repository_detector: RepositoryDetector
     logger: Logger
@@ -47,7 +44,4 @@ class PrefetchDirectoryUseCaseImpl:
             rev=revision,
             prefetch_options=request.prefetch_options,
         )
-        if request.rendering_format == RenderingFormat.json:
-            self.json_presenter.present(prefetch_result)
-        else:
-            self.nix_presenter.present(prefetch_result)
+        self.presenter.present(prefetch_result)
